@@ -28,6 +28,9 @@ from .variables import dimensions, \
 from .utils import parse_meta_file, read_mds, parse_available_diagnostics,\
     get_extra_metadata
 
+from .file_utils import listdir, listdir_startswith, listdir_endswith, \
+    listdir_startsandendswith, listdir_fnmatch
+
 # Python2/3 compatibility
 if (sys.version_info > (3, 0)):
     stringtypes = [str]
@@ -39,7 +42,7 @@ try:
     from xarray.core.pycompat import OrderedDict
 except ImportError:
     from collections import OrderedDict
-    
+
 # should we hard code this?
 LLC_NUM_FACES = 13
 LLC_FACE_DIMNAME = 'face'
@@ -48,7 +51,7 @@ LLC_FACE_DIMNAME = 'face'
 def open_mdsdataset(data_dir, grid_dir=None,
                     iters='all', prefix=None, read_grid=True,
                     delta_t=1, ref_date=None, calendar='gregorian',
-                    geometry='sphericalpolar',
+                    levels=None, geometry='sphericalpolar',
                     grid_vars_to_coords=True, swap_dims=None,
                     endian=">", chunks=None,
                     ignore_unknown_vars=False, default_dtype=None,
@@ -78,6 +81,9 @@ def open_mdsdataset(data_dir, grid_dir=None,
         e.g. "1990-1-1 0:0:0" (See CF conventions [1]_)
     calendar : string, optional
         A calendar allowed by CF conventions [1]_
+    levels : list or slice, optional
+        A list or slice of the indexes of the grid levels to read
+        Same syntax as in the data.diagnostics file
     geometry : {'sphericalpolar', 'cartesian', 'llc', 'curvilinear'}
         MITgcm grid geometry specifier
     grid_vars_to_coords : boolean, optional
@@ -157,6 +163,13 @@ def open_mdsdataset(data_dir, grid_dir=None,
     else:
         pass
 
+    # if levels s a slice or a list, a subset of levels is needed
+    if levels is not None and nz is not None:
+        warnings.warn('levels has been set, nz will be ignored.')
+        nz = None
+    if isinstance(levels, slice):
+        levels = np.arange(levels.start, levels.stop)
+
     # We either have a single iter, in which case we create a fresh store,
     # or a list of iters, in which case we combine.
     if iters == 'all':
@@ -168,7 +181,7 @@ def open_mdsdataset(data_dir, grid_dir=None,
             iternum = int(iters)
         # if not we probably have some kind of list
         except TypeError:
-            if len(iters) == 1:
+            if len(iters) == 1 and levels is None:
                 iternum = int(iters[0])
             else:
                 # We have to check to make sure we have the same prefixes at
@@ -200,21 +213,33 @@ def open_mdsdataset(data_dir, grid_dir=None,
                     ignore_unknown_vars=ignore_unknown_vars,
                     default_dtype=default_dtype,
                     nx=nx, ny=ny, nz=nz, llc_method=llc_method,
-                    extra_metadata=extra_metadata)
+                    levels=levels, extra_metadata=extra_metadata)
                 datasets = [open_mdsdataset(
                         data_dir, iters=iternum, read_grid=False, **kwargs)
                     for iternum in iters]
                 # now add the grid
                 if read_grid:
                     if 'iters' in kwargs:
-                        kwargs.remove('iters')
+                        kwargs.pop('iters')
                     if 'read_grid' in kwargs:
-                        kwargs.remove('read_grid')
-                    datasets.insert(0,
-                        open_mdsdataset(data_dir, iters=None, read_grid=True,
-                                        **kwargs))
+                        kwargs.pop('read_grid')
+                    if levels is not None:
+                        kwargs.pop('nz')
+                        kwargs.pop('levels')
+                    grid_dataset = open_mdsdataset(data_dir, iters=None,
+                                                   read_grid=True, **kwargs)
+                    if levels is not None:
+                        grid_dataset = grid_dataset.isel(**{coord: levels
+                                    for coord in ['k', 'k_l', 'k_u', 'k_p1']})
+                    datasets.insert(0, grid_dataset)
                 # apply chunking
-                ds = xr.auto_combine(datasets)
+                if sys.version_info[0] < 3:
+                    ds = xr.auto_combine(datasets)
+                elif xr.__version__ < '0.15.2':
+                    ds = xr.combine_by_coords(datasets)
+                else:
+                    ds = xr.combine_by_coords(datasets, compat='override', coords='minimal', combine_attrs='drop')
+
                 if swap_dims:
                     ds = _swap_dimensions(ds, geometry)
                 if grid_vars_to_coords:
@@ -227,7 +252,7 @@ def open_mdsdataset(data_dir, grid_dir=None,
                           ignore_unknown_vars=ignore_unknown_vars,
                           default_dtype=default_dtype,
                           nx=nx, ny=ny, nz=nz, llc_method=llc_method,
-                          extra_metadata=extra_metadata)
+                          levels=levels, extra_metadata=extra_metadata)
     ds = xr.Dataset.load_store(store)
 
     if swap_dims:
@@ -235,23 +260,8 @@ def open_mdsdataset(data_dir, grid_dir=None,
     if grid_vars_to_coords:
         ds = _set_coords(ds)
 
-    if ref_date and 'time' in ds:
-        # our own little hack for decoding cf datetimes
-        encoding = {}
-        units = ds.time.attrs.get('units') or ''
-        if 'since' in units:
-            calendar = ds.time.attrs.get('calendar')
-            encoding['units'] = units
-            del ds.time.attrs['units']
-            if calendar:
-                encoding['calendar'] = calendar
-                del ds.time.attrs['calendar']
-            ds.time.data = (xr.coding.times
-                            .decode_cf_datetime(ds.time.data, units=units,
-                                            calendar=calendar))
-            # this doesn't seem to have any effect, so we remove it
-            #ds.time.encoding = encoding
-
+    if 'time' in ds:
+        ds['time'] = xr.decode_cf(ds[['time']])['time']
 
     # do we need more fancy logic (like open_dataset), or is this enough
     if chunks is not None:
@@ -307,9 +317,12 @@ def _swap_dimensions(ds, geometry, drop_old=True):
     for orig_dim in ds.dims:
         if 'swap_dim' in ds[orig_dim].attrs:
             new_dim = ds[orig_dim].attrs['swap_dim']
-            ds = ds.swap_dims({orig_dim: new_dim})
+            ds = ds.swap_dims({orig_dim:  new_dim})
             if drop_old:
-                ds = ds.drop(orig_dim)
+                if sys.version_info[0] < 3:
+                    ds = ds.drop(orig_dim)
+                else:
+                    ds = ds.drop_vars(orig_dim)
     return ds
 
 
@@ -323,7 +336,7 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
                  endian='>', ignore_unknown_vars=False,
                  default_dtype=np.dtype('f4'),
                  nx=None, ny=None, nz=None, llc_method="smallchunks",
-                 extra_metadata=None):
+                 levels=None, extra_metadata=None):
         """
         This is not a user-facing class. See open_mdsdataset for argument
         documentation. The only ones which are distinct are.
@@ -432,8 +445,12 @@ class _MDSDataStore(xr.backends.common.AbstractDataStore):
         # http://pycomodo.forge.imag.fr/norm.html
         irange = np.arange(self.nx)
         jrange = np.arange(self.ny)
-        krange = np.arange(self.nz)
-        krange_p1 = np.arange(self.nz+1)
+        if levels is None:
+            krange = np.arange(self.nz)
+            krange_p1 = np.arange(self.nz+1)
+        else:
+            krange = levels
+            krange_p1 = levels + [levels[-1] + 1]
         # the keys are `standard_name` attribute
         dimension_data = {
             "x_grid_index": irange,
@@ -732,7 +749,7 @@ def _guess_model_horiz_dims(data_dir, is_llc=False):
 
 def _guess_layers(data_dir):
     """Return a dict matching layers suffixes to dimension length."""
-    layers_files = glob(os.path.join(data_dir, 'layers*.meta'))
+    layers_files = listdir_startsandendswith(data_dir, 'layers', '.meta')
     all_layers = {}
     for fname in layers_files:
         # make sure to exclude filenames such as
@@ -740,13 +757,13 @@ def _guess_layers(data_dir):
         if not re.search('\.\d{10}\.', fname):
             # should turn "foo/bar/layers1RHO.meta" into "1RHO"
             layers_suf = os.path.splitext(os.path.basename(fname))[0][6:]
-            meta = parse_meta_file(fname)
+            meta = parse_meta_file(os.path.join(data_dir, fname))
             Nlayers = meta['dimList'][2][2]
             all_layers[layers_suf] = Nlayers
     return all_layers
 
 
-def _get_all_grid_variables(geometry, grid_dir, layers={}):
+def _get_all_grid_variables(geometry, grid_dir=None, layers={}):
     """"Put all the relevant grid metadata into one big dictionary."""
     possible_hcoords = {'cartesian': horizontal_coordinates_cartesian,
                         'llc': horizontal_coordinates_llc,
@@ -755,7 +772,7 @@ def _get_all_grid_variables(geometry, grid_dir, layers={}):
     hcoords = possible_hcoords[geometry]
 
     # look for extra variables, if they exist in grid_dir
-    extravars = _get_extra_grid_variables(grid_dir)
+    extravars = _get_extra_grid_variables(grid_dir) if grid_dir is not None else {}
 
     allvars = [hcoords, vertical_coordinates, horizontal_grid_variables,
                vertical_grid_variables, volume_grid_variables, mask_variables,
@@ -775,12 +792,16 @@ def _get_extra_grid_variables(grid_dir):
        Then return the variable information for each of these"""
     extra_grid = {}
 
-    all_datafiles = glob(os.path.join(grid_dir, '*.data'))
+    fnames = dict([[val['filename'],key] for key,val in extra_grid_variables.items() if 'filename' in val])
+
+    all_datafiles = listdir_endswith(grid_dir, '.data')
     for f in all_datafiles:
         prefix = os.path.split(f[:-5])[-1]
         # Only consider what we find that matches extra_grid_vars
         if prefix in extra_grid_variables:
             extra_grid[prefix] = extra_grid_variables[prefix]
+        elif prefix in fnames:
+            extra_grid[fnames[prefix]] = extra_grid_variables[fnames[prefix]]
 
     return extra_grid
 
@@ -820,7 +841,7 @@ def _get_all_data_variables(data_dir, grid_dir, layers):
     """"Put all the relevant data metadata into one big dictionary."""
     allvars = [state_variables]
     allvars.append(package_state_variables)
-    
+
     # add others from available_diagnostics.log
     # search in the data dir
     fnameD = os.path.join(data_dir, 'available_diagnostics.log')
@@ -869,7 +890,7 @@ def _get_all_iternums(data_dir, file_prefixes=None,
                       file_format='*.??????????.data'):
     """Scan a directory for all iteration number suffixes."""
     iternums = set()
-    all_datafiles = glob(os.path.join(data_dir, file_format))
+    all_datafiles = listdir_fnmatch(data_dir, file_format)
     istart = file_format.find('?')-len(file_format)
     iend = file_format.rfind('?')-len(file_format)+1
     for f in all_datafiles:
@@ -898,7 +919,7 @@ def _get_all_matching_prefixes(data_dir, iternum, file_prefixes=None,
     if iternum is None:
         return []
     prefixes = set()
-    all_datafiles = glob(os.path.join(data_dir, '*.%010d.data' % iternum))
+    all_datafiles = listdir_endswith(data_dir, '.%010d.data' % iternum)
     for f in all_datafiles:
         iternum = int(f[-15:-5])
         prefix = os.path.split(f[:-16])[-1]
